#! /bin/sh
# @(#)cleanmidas.sh	1.1 (ESO-IPG) 07/12/91 14:15:58
# .COPYRIGHT: Copyright (c) 1988 European Southern Observatory,
#                                         all rights reserved
# .TYPE           command
# .NAME           cleanmidas.sh
# .LANGUAGE       shell script
# .ENVIRONMENT    Unix Systems. Executable under SHELL and C-SHELL
# .COMMENTS       Installation procedure of the MIDAS system starting from
#                 scratch.
#                 Usage: installmidas system [options]
#
# .REMARKS        The external variable $MIDASHOME and $MIDVERS must be set 
#
# .AUTHOR         Carlos Guirao
# .VERSION 1.1    30-Oct-1989:		Installation.
# .VERSION 1.2    05-Dec-1989:		Adding "echo" definition

echo=echo
if [ "`echo -n`" = "-n" ] ; then
        SV_NONL="\c"
else
        echo="echo -n"
fi

#
# First of all, check $MIDASHOME and $MIDVERS
#
#clear

if [ $MIDASHOME ]
then
        continue
else
        echo "\$MIDASHOME undefined"
        echo "Please, set \$MIDASHOME and \$MIDVERS before running: $0"
        exit
fi
if [ $MIDVERS ]
then
        continue
else
        echo "\$MIDVERS is undefined"
        echo "Please, set \$MIDASHOME and \$MIDVERS before running: $0"
        exit
fi

MID_INSTALL=$MIDASHOME/$MIDVERS/install/unix
cd $MID_INSTALL


#
# START
#
#clear
task="unknown"
while :
do
echo ""
echo "	       MIDAS DELETE MENU:"
echo "	===================================="
echo "	1 - Delete only object files."
echo "	2 - Delete object and source files."
echo "	3 - Delete object, source files and libraries."
echo "	4 - Delete documentation."
echo "	5 - Delete executable files."
echo "	q - Quit."
echo ""
$echo "Select: " $SV_NONL

read task
task=`echo $task | tr A-Z a-z`

echo ""
case $task in
    1) 
	echo "1. This option will delete all files *.o"
	echo "   under $MIDASHOME/$MIDVERS"
	$echo "   Total number of blocks to be deleted (wait): " $SV_NONL
	find $MIDASHOME/$MIDVERS -name "*.o" -exec ls -s {} \; | \
	awk 'BEGIN { size=0 } { size=size+$1 } \
	     END {print size; if (size == 0) exit 1}'
	;;
    2) 
	echo "2. This option will delete all files *.o *.for *.c"
	echo "   under $MIDASHOME/$MIDVERS"
	$echo "   Total number of blocks to be deleted (wait): " $SV_NONL
	find $MIDASHOME/$MIDVERS \( \
		-name "*.o" -o \
		-name "*.for" -o  \
		-name "*.c" \) -exec ls -s {} \; | \
	awk 'BEGIN { size=0 } { size=size+$1 } \
	     END {print size; if (size == 0) exit 1}'
	;;
    3) 
	echo "3. This option will delete all files *.o *.for *.c *.a"
	echo "   under $MIDASHOME/$MIDVERS"
	$echo "   Total number of blocks to be deleted (wait): " $SV_NONL
	find $MIDASHOME/$MIDVERS \( \
		-name "*.o" -o \
		-name "*.for" -o  \
		-name "*.a" -o  \
		-name "*.c" \) -exec ls -s {} \; | \
	awk 'BEGIN { size=0 } { size=size+$1 } \
	     END {print size; if (size == 0) exit 1}'
	;;
    4) 
	echo "4. This option will delete all files "
	echo "	 under $MIDASHOME/$MIDVERS/doc"
	$echo "   Total number of blocks to be deleted: " $SV_NONL
	du -s $MIDASHOME/$MIDVERS/doc | awk '{print $1; if (size == 0) exit 1}'
	;;
    5)  /bin/sh $MID_INSTALL/delete_applic
	continue
	;;
    q) 
	exit
	;;
    *)  echo "Selection unknown"
	continue
	;;
esac

if [ $? != 0 ]; then
    continue
fi

echo ""
$echo "Do you want to continue [yn]? (y): " $SV_NONL
read answ
if [ -z "$answ" ]; then
    answ=y
fi
if [ "$answ" != "y" -a "$answ" != "Y" ]
then
    continue
fi
#exit

echo "Start removing."
case $task in
     1)
	echo 'find $MIDASHOME/$MIDVERS -name "*.o" -exec rm -f {} \;'
	find $MIDASHOME/$MIDVERS -name "*.o" -exec rm -f {} \;
	;;
     2)
	echo 'find $MIDASHOME/$MIDVERS \( \
		-name "*.o" -o \
		-name "*.for" -o  \
		-name "*.c" \) -exec rm -f {} \;'
	find $MIDASHOME/$MIDVERS \( \
		-name "*.o" -o \
		-name "*.for" -o  \
		-name "*.c" \) -exec rm -f {} \;
	;;
     3)
	echo 'find $MIDASHOME/$MIDVERS \( \
		-name "*.o" -o \
		-name "*.for" -o  \
		-name "*.c" -o  \
		-name "*.a" \) -exec rm -f {} \;'
	find $MIDASHOME/$MIDVERS \( \
		-name "*.o" -o \
		-name "*.for" -o  \
		-name "*.c" -o  \
		-name "*.a" \) -exec rm -f {} \;
	;;
     4)
	echo 'rm -r $MIDASHOME/$MIDVERS/doc'
	rm -r $MIDASHOME/$MIDVERS/doc
	;;
esac

echo "Done."
done
