#! /bin/sh
# @(#)installmidas1.sh	1.1 (ESO-IPG) 07/12/91 14:16:02
# .COPYRIGHT: Copyright (c) 1988 European Southern Observatory,
#                                         all rights reserved
# .TYPE           command
# .NAME           installmidas1.sh
# .LANGUAGE       shell script
# .ENVIRONMENT    Unix Systems. Executable under SHELL and C-SHELL
# .COMMENTS       Installation procedure of the MIDAS system starting from
#                 scratch.
#                 Usage: installmidas system [options]
#
# .REMARKS        The external variable $MIDASHOME and $MIDVERS must be set 
#
# .AUTHOR         Carlos Guirao
# .VERSION 1.1    25-Oct-1989:		Implementation
# .VERSION 1.2    05-Dec-1989:		Adding "echo" definition
# .VERSION 1.3    910219:               Removing System name argument

echo=echo
if [ "`echo -n`" = "-n" ] ; then
    SV_NONL="\c"
else
    echo="echo -n"
fi

cd `echo $0 | sed -e 's/[^\/]*$//' -e 's/^$/./' -e 's/\/$//'` #cd `dirname $0`
MID_INSTALL=`pwd`
VERSDIR=`echo $MID_INSTALL | sed 's/\/install\/unix$//'`
MIDVERS=`echo $VERSDIR | sed -e 's/^.*\///'`    #MIDVERS=`basename $VERSDIR`
MIDASHOME=`echo $VERSDIR | sed -e 's/[^\/]*$//' -e 's/^$/./' -e 's/\/$//'`
						#MIDASHOME=`dirname $VERSDIR`
export MIDASHOME MIDVERS MID_INSTALL

clear
if [ ! -f "$MID_INSTALL/midas.cnf" ] ; then
    echo ""
    echo "ERROR: The configuration file <midas.cnf> does not exist"
    echo "Run <configmidas> and select a configuration for MIDAS"
    exit
fi

if [ ! -f "$MIDASHOME/local/make_options" ] ; then
    echo ""
    echo "ERROR: The file <$MIDASHOME/local/make_options> does not exist."
    echo "Run <preinstall> before to continue with installmidas."
    exit
fi

if [ ! -d "$MIDASHOME/tmp" ] ; then
    echo "Directory: <$MIDASHOME/tmp> does not exist."
    mkdir $MIDASHOME/tmp
    if [ $? != 0 ] ; then
	echo "ERROR: <$MIDASHOME/tmp> cannot be created."
	echo "Ask your system manager."
	echo "Bye..."
	exit
    fi
    echo "<$MIDASHOME/tmp> created."
    chmod 777 $MIDASHOME/tmp
fi

while :
do
    if ar t $MIDASHOME/$MIDVERS/lib/mathlib.a >/dev/null 2>&1
    then
	break
    fi
    echo ""
    echo "Type the full pathname of a NAG library or CR if you do not have any."
    $echo "Pathname: " $SV_NONL
    read answ
    if [ -z "$answ" ]; then
	cd $MIDASHOME/$MIDVERS/libsrc/mathlib
	/bin/sh $MIDASHOME/$MIDVERS/system/unix/makemidas 
	if [ $? !=  0 ]; then
	    echo "Error creating a dummy NAG library."
	    exit 1
	else
	    cd $MID_INSTALL
	    continue
	fi
    fi
    if ar t $answ >/dev/null 2>&1
    then
	if ln -s $answ $MIDASHOME/$MIDVERS/lib/mathlib.a 
        then
	    continue
	else
	    cp $answ $MIDASHOME/$MIDVERS/lib/mathlib.a
	fi
    else
	echo "$answ no such library."
	continue
    fi
done

if [ -f "$MIDASHOME/local/README" ] ; then
    cat $MIDASHOME/local/README
fi

clear
echo ""
echo "MIDAS INSTALLATION PROCEDURE"
echo "============================"
echo "MIDASHOME: $MIDASHOME"
echo "MIDVERS:   $MIDVERS"
echo "MAKE_OPTIONS:"
awk -F# '{ if ($1 != "") {printf "\t  %s\n",$1} }' $MIDASHOME/local/make_options
echo ""

$echo "Do you want to check the OS library <oslib.a> [yn]? (y): " $SV_NONL
read answ
if [ -z "$answ" ]; then
    answ=y
fi
if [ "$answ" != "y" -a "$answ" != "Y" ]
then
    continue
else
    set -x
    cd $MIDASHOME/$MIDVERS/system/machine
    /bin/sh $MIDASHOME/$MIDVERS/system/unix/makemidas ../../incl/computer.h
    cd $MIDASHOME/$MIDVERS/libsrc/os/unix
    /bin/sh $MIDASHOME/$MIDVERS/system/unix/makemidas clean
    /bin/sh $MIDASHOME/$MIDVERS/system/unix/makemidas install
    set +x
    /bin/sh $MIDASHOME/$MIDVERS/system/unix/makemidas
    if [ $? != 0 ]; then
	echo ""
	echo ' **********************************************'
	echo ' *               ATTENTION                    *'
	echo ' * There was a severe error in your <oslib.a> *'
	echo ' * that should be corrected before continuing *'
	echo ' * with the MIDAS installation.               *'
	echo ' *                                            *'
	echo ' * Go to $MIDASHOME/$MIDVERS/libsrc/os/unix   *'
	echo ' * and type by hand:                          *'
	echo ' *                                            *'
        echo ' *     % $mmake clean                         *'
        echo ' *     % $mmake install                       *'
        echo ' *     % $mmake                               *'
	echo ' *                                            *'
        echo ' * The sequence above should be executed      *'
        echo ' * without any error (Warnings are tolerated) *'
        echo ' * MIDAS installation aborted !!. Bye...      *'
	echo ' **********************************************'
        echo ""
	$echo "Type return to exit: " $SV_NONL
	read return
	exit
    fi
fi

echo ""
echo "WARNING: MIDAS installation will delete all dependent files."
echo "         It will run in background and the output will be sent to"
echo "         the file <$MIDASHOME/tmp/install.$$>"
echo ""
$echo "Do you want to continue [yn]? (y): " $SV_NONL
read answ
if [ -z "$answ" ]; then
    answ=y
fi
if [ "$answ" != "y" -a "$answ" != "Y" ]
then
    echo "Bye"
    exit 0
fi

/bin/time /bin/sh $MID_INSTALL/installmidas -i > $MIDASHOME/tmp/install.$$ 2>&1 &
echo "Running installmidas in background"
echo "Results are coming in $MIDASHOME/tmp/install.$$"
